==> ejc-wzxt-impl-3.0.0-20211105.095130-118-sources.jar: com/ejianc/business/wzxt/controller/PickingOutStoreController.java <==
package com.ejianc.business.wzxt.controller;

import java.io.Serializable;

import com.ejianc.business.wzxt.service.IPickingOutStoreDetailService;
import com.ejianc.business.wzxt.vo.*;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.time.DateFormatUtil;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.wzxt.bean.PickingOutStoreEntity;
import com.ejianc.business.wzxt.service.IPickingOutStoreService;

/**
 * 领料出库（主）
 * 
 * @author generator
 * 
 */
@Controller
@RequestMapping("pickingOutStore")
public class PickingOutStoreController implements Serializable {
	private static final long serialVersionUID = 1L;
	
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "MATERIAL-OUTSTORE";//此处需要根据实际修改
    
    @Autowired
    private IPickingOutStoreService service;
    @Autowired
    private IPickingOutStoreDetailService detailService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<PickingOutStoreVO> saveOrUpdate(@RequestBody PickingOutStoreVO saveorUpdateVO) {
    	PickingOutStoreEntity entity = BeanMapper.map(saveorUpdateVO, PickingOutStoreEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            CommonResponse<String> billCode = billCodeApi.getCodeBatchByRuleCode(BILL_CODE, InvocationInfoProxy.getTenantid());
            if(billCode.isSuccess()) {
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	PickingOutStoreVO vo = BeanMapper.map(entity, PickingOutStoreVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }
    
    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<PickingOutStoreVO> queryDetail(Long id) {
    	PickingOutStoreEntity entity = service.selectById(id);
    	PickingOutStoreVO vo = BeanMapper.map(entity, PickingOutStoreVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }
    
    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<PickingOutStoreVO> vos) {
        service.removeByIds(vos.stream().map(PickingOutStoreVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }
    
    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<PickingOutStoreVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("materialNames");
        fuzzyFields.add("orgName");
        fuzzyFields.add("pickingUnitName");
        fuzzyFields.add("pickingName");
        fuzzyFields.add("creatorName");
        fuzzyFields.add("projectName");
        fuzzyFields.add("useFor");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));

        IPage<PickingOutStoreEntity> page = service.queryPage(param,false);
        IPage<PickingOutStoreVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), PickingOutStoreVO.class));
        
        return CommonResponse.success("查询列表数据成功！",pageData);
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("materialNames");
        fuzzyFields.add("orgName");
        fuzzyFields.add("pickingUnitName");
        fuzzyFields.add("pickingName");
        fuzzyFields.add("creatorName");
        fuzzyFields.add("projectName");
        fuzzyFields.add("useFor");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<PickingOutStoreEntity> list = service.queryList(param);
        List<PickingOutStoreExportVO> exportVOS = new ArrayList<>();
        list.forEach(val ->{
            PickingOutStoreExportVO exportVO = BeanMapper.map(val, PickingOutStoreExportVO.class);
            exportVO.setOutDate(DateFormatUtil.formatDate("yyyy-MM-dd",val.getOutDate()));
            exportVO.setCreatorTime(DateFormatUtil.formatDate("yyyy-MM-dd",val.getCreatorTime()));
            switch (val.getBillState()){
                case 0: exportVO.setBillState("自由态");break;
                case 1: exportVO.setBillState("已提交");break;
                case 2: exportVO.setBillState("审批中");break;
                case 3: exportVO.setBillState("审批通过");break;
                case 4: exportVO.setBillState("审批驳回");break;
                case 5: exportVO.setBillState("审批中");break;
            }
            exportVOS.add(exportVO);
        });
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", exportVOS);
        ExcelExport.getInstance().export("pickingOutStoreExport.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refPickingOutStoreData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<CheckDetailVO>> refPickingOutStoreData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("materialName");
        fuzzyFields.add("materialSpec");

        IPage<CheckDetailVO> entityPage =
                detailService.queryNumPageData(searchText,pageNumber,pageSize);
        return CommonResponse.success("查询参照数据成功！",entityPage);
     }
}

==> ejc-wzxt-impl-3.0.0-20230810.055312-139-sources.jar: com/ejianc/business/wzxt/controller/PickingOutStoreController.java <==
package com.ejianc.business.wzxt.controller;

import java.io.Serializable;

import com.ejianc.business.wzxt.service.IPickingOutStoreDetailService;
import com.ejianc.business.wzxt.vo.*;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.time.DateFormatUtil;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.wzxt.bean.PickingOutStoreEntity;
import com.ejianc.business.wzxt.service.IPickingOutStoreService;

/**
 * 领料出库（主）
 * 
 * @author generator
 * 
 */
@Controller
@RequestMapping("pickingOutStore")
public class PickingOutStoreController implements Serializable {
	private static final long serialVersionUID = 1L;
	
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "PICKING-OUTSTORE";//此处需要根据实际修改
    
    @Autowired
    private IPickingOutStoreService service;
    @Autowired
    private IPickingOutStoreDetailService detailService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<PickingOutStoreVO> saveOrUpdate(@RequestBody PickingOutStoreVO saveorUpdateVO) {
    	PickingOutStoreEntity entity = BeanMapper.map(saveorUpdateVO, PickingOutStoreEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            CommonResponse<String> billCode = billCodeApi.getCodeBatchByRuleCode(BILL_CODE, InvocationInfoProxy.getTenantid());
            if(billCode.isSuccess()) {
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	PickingOutStoreVO vo = BeanMapper.map(entity, PickingOutStoreVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }
    
    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<PickingOutStoreVO> queryDetail(Long id) {
    	PickingOutStoreEntity entity = service.selectById(id);
    	PickingOutStoreVO vo = BeanMapper.map(entity, PickingOutStoreVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }
    
    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<PickingOutStoreVO> vos) {
        service.removeByIds(vos.stream().map(PickingOutStoreVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }
    
    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<PickingOutStoreVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("materialNames");
        fuzzyFields.add("orgName");
        fuzzyFields.add("pickingUnitName");
        fuzzyFields.add("pickingName");
        fuzzyFields.add("creatorName");
        fuzzyFields.add("projectName");
        fuzzyFields.add("useFor");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));

        IPage<PickingOutStoreEntity> page = service.queryPage(param,false);
        IPage<PickingOutStoreVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), PickingOutStoreVO.class));
        
        return CommonResponse.success("查询列表数据成功！",pageData);
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("materialNames");
        fuzzyFields.add("orgName");
        fuzzyFields.add("pickingUnitName");
        fuzzyFields.add("pickingName");
        fuzzyFields.add("creatorName");
        fuzzyFields.add("projectName");
        fuzzyFields.add("useFor");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<PickingOutStoreEntity> list = service.queryList(param);
        List<PickingOutStoreExportVO> exportVOS = new ArrayList<>();
        list.forEach(val ->{
            PickingOutStoreExportVO exportVO = BeanMapper.map(val, PickingOutStoreExportVO.class);
            exportVO.setOutDate(DateFormatUtil.formatDate("yyyy-MM-dd",val.getOutDate()));
            exportVO.setCreatorTime(DateFormatUtil.formatDate("yyyy-MM-dd HH:mm:ss",val.getCreatorTime()));
            switch (val.getBillState()){
                case 0: exportVO.setBillState("自由态");break;
                case 1: exportVO.setBillState("已提交");break;
                case 2: exportVO.setBillState("审批中");break;
                case 3: exportVO.setBillState("审批通过");break;
                case 4: exportVO.setBillState("审批驳回");break;
                case 5: exportVO.setBillState("审批中");break;
            }
            exportVOS.add(exportVO);
        });
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", exportVOS);
        ExcelExport.getInstance().export("pickingOutStoreExport.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refPickingOutStoreData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<CheckDetailVO>> refPickingOutStoreData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("materialName");
        fuzzyFields.add("materialSpec");

        IPage<CheckDetailVO> entityPage =
                detailService.queryNumPageData(searchText,pageNumber,pageSize);
        return CommonResponse.success("查询参照数据成功！",entityPage);
     }
}
